@@ -21,7 +21,7 @@ import networkx as nx
 
 from outdated import check_outdated # type: ignore
 
-from tgwrap.lib import TgWrap, Printer
+from tgwrap.lib import TgWrap
 
 from . import __version__
 
